Enum polkadot_node_subsystem_types::messages::ApprovalDistributionMessage [−][src]
pub enum ApprovalDistributionMessage {
NewBlocks(Vec<BlockApprovalMeta>),
DistributeAssignment(IndirectAssignmentCert, CandidateIndex),
DistributeApproval(IndirectSignedApprovalVote),
NetworkBridgeUpdateV1(NetworkBridgeEvent<ApprovalDistributionMessage>),
}Expand description
Message to the Approval Distribution subsystem.
Variants
NewBlocks(Vec<BlockApprovalMeta>)Notify the ApprovalDistribution subsystem about new blocks
and the candidates contained within them.
Tuple Fields of NewBlocks
0: Vec<BlockApprovalMeta>DistributeAssignment(IndirectAssignmentCert, CandidateIndex)Distribute an assignment cert from the local validator. The cert is assumed to be valid, relevant, and for the given relay-parent and validator index.
Tuple Fields of DistributeAssignment
DistributeApproval(IndirectSignedApprovalVote)Distribute an approval vote for the local validator. The approval vote is assumed to be valid, relevant, and the corresponding approval already issued. If not, the subsystem is free to drop the message.
Tuple Fields of DistributeApproval
NetworkBridgeUpdateV1(NetworkBridgeEvent<ApprovalDistributionMessage>)An update from the network bridge.
Tuple Fields of NetworkBridgeUpdateV1