Enum polkadot_node_subsystem_types::messages::CandidateBackingMessage [−][src]
pub enum CandidateBackingMessage {
GetBackedCandidates(Hash, Vec<CandidateHash>, Sender<Vec<BackedCandidate>>),
Second(Hash, CandidateReceipt, PoV),
Statement(Hash, SignedFullStatement),
}Expand description
Messages received by the Candidate Backing subsystem.
Variants
GetBackedCandidates(Hash, Vec<CandidateHash>, Sender<Vec<BackedCandidate>>)Requests a set of backable candidates that could be backed in a child of the given relay-parent, referenced by its hash.
Tuple Fields of GetBackedCandidates
Second(Hash, CandidateReceipt, PoV)Note that the Candidate Backing subsystem should second the given candidate in the context of the given relay-parent (ref. by hash). This candidate must be validated.
Tuple Fields of Second
Statement(Hash, SignedFullStatement)Note a validator’s statement about a particular candidate. Disagreements about validity must be escalated to a broader check by Misbehavior Arbitration. Agreements are simply tallied until a quorum is reached.
Tuple Fields of Statement
0: Hash1: SignedFullStatementTrait Implementations
Returns the relay parent this message is bound to.