Enum polkadot_node_subsystem_types::messages::ChainApiMessage [−][src]
pub enum ChainApiMessage {
BlockNumber(Hash, ChainApiResponseChannel<Option<BlockNumber>>),
BlockHeader(Hash, ChainApiResponseChannel<Option<BlockHeader>>),
BlockWeight(Hash, ChainApiResponseChannel<Option<BlockWeight>>),
FinalizedBlockHash(BlockNumber, ChainApiResponseChannel<Option<Hash>>),
FinalizedBlockNumber(ChainApiResponseChannel<BlockNumber>),
Ancestors {
hash: Hash,
k: usize,
response_channel: ChainApiResponseChannel<Vec<Hash>>,
},
}Expand description
Chain API request subsystem message.
Variants
BlockNumber(Hash, ChainApiResponseChannel<Option<BlockNumber>>)Request the block number by hash.
Returns None if a block with the given hash is not present in the db.
Tuple Fields of BlockNumber
BlockHeader(Hash, ChainApiResponseChannel<Option<BlockHeader>>)Request the block header by hash.
Returns None if a block with the given hash is not present in the db.
Tuple Fields of BlockHeader
BlockWeight(Hash, ChainApiResponseChannel<Option<BlockWeight>>)Get the cumulative weight of the given block, by hash.
If the block or weight is unknown, this returns None.
Note: this is the weight within the low-level fork-choice rule, not the high-level one implemented in the chain-selection subsystem.
Weight is used for comparing blocks in a fork-choice rule.
Tuple Fields of BlockWeight
FinalizedBlockHash(BlockNumber, ChainApiResponseChannel<Option<Hash>>)Request the finalized block hash by number.
Returns None if a block with the given number is not present in the db.
Note: the caller must ensure the block is finalized.
Tuple Fields of FinalizedBlockHash
FinalizedBlockNumber(ChainApiResponseChannel<BlockNumber>)Request the last finalized block number. This request always succeeds.
Tuple Fields of FinalizedBlockNumber
Request the k ancestors block hashes of a block with the given hash.
The response channel may return a Vec of size up to k
filled with ancestors hashes with the following order:
parent, grandparent, …
Fields of Ancestors
hash: HashThe hash of the block in question.
k: usizeThe number of ancestors to request.
response_channel: ChainApiResponseChannel<Vec<Hash>>The response channel.
Implementations
If the current variant contains the relay parent hash, return it.